@@ -15,7 +15,7 @@ def gen_model(
 
     Args:
         text: space delimited words/chinese chars/numbers
-
+            or normal Chinese text: see token_pattern below
     Returns:
         TfidfVectorizer
     """
@@ -34,6 +34,7 @@ def gen_model(
         ).fit(text)
     except Exception as e:
         logger.error(e)
-        raise SystemExit(1)
+        raise
+        # raise SystemExit(1) from e
 
     return model
